API_PATH = "/api/v1"


class Resource:
    GW_USER = "gw_user"
    GW_HOLE = "hole"
    GW_SENSOR = "sensor"
    GW_GOLF_COURSE = "golf_course"
    GW_ALERT = "alert"
    GW_MENU = "menu"
    GW_REPORT = "report"
